@plotimage.pro
;;
fct1=2.    ;; Factor for increasing resolution of map
fct2=1.    ;; Factor for increasing ratio of map size to aperture size
nx=fct1*1024  ;; Total nr of pixels
nwf=0.5*nx*fct2/(2*fct1)   ;; Window in Fourier space to show
nw=2*nx/(4*fct2)    ;; Window in real space to show
xm=10.     ;; Total half-width
r=1./fct2  ;; Radius of the circular aperture
d=3.48*r   ;; Distance between the two circular apertures
;d=6.*r   ;; Distance between the two circular apertures
xx=rebin(2*xm*dindgen(nx)/(nx-1.d0)-xm,nx,nx)
yy=transpose(xx)
;;
;; Make two circular apertures
;;
mask=dblarr(nx,nx)
;;
;; ...Left telescope
;;
rr=sqrt((xx+d/2)^2+yy^2)
ii=where(rr lt r)
mask[ii]=1.d0
;;
;; ...Right telescope
;;
rr=sqrt((xx-d/2)^2+yy^2)
ii=where(rr lt r)
mask[ii]=1.d0
;;
;; ...Third telescope (for demonstration)
;;
;rr=sqrt((xx-d/2)^2+(yy-d/2)^2)
;ii=where(rr lt r)
;mask[ii]=1.d0
;;
;; Make the Fourier transform 
;;
ft=fft(mask)
;;
;; Move Fourier transform 1/2 an image size to right and to top,
;; so that the PSF is in the center of the Fourier-plane image
;;
dum=ft*0.d0
dum[0:nx/2-1,*] = ft[nx/2:nx-1,*]
dum[nx/2:nx-1,*] = ft[0:nx/2-1,*]
ft[*,0:nx/2-1] = dum[*,nx/2:nx-1]
ft[*,nx/2:nx-1] = dum[*,0:nx/2-1]
;;
;; Make the absolute-value-squared, and normalize to 1
;;
ftabs2=abs(ft)^2
ftabs2=ftabs2/max(ftabs2)
;;
;; Plot to image
;;
ysize=400
window,xsize=2*ysize,ysize=ysize
;;
;; ...On the left: The original two subapertures
;;
plotimage,alog10(mask[(nx-nw)/2:(nx+nw)/2-1,(nx-nw)/2:(nx+nw)/2-1]>1d-4),position=[0,0.0,0.5,1]
plot,[0,1],[0,1],xstyle=7,ystyle=7,/nodata,/noerase,position=[0,0.0,0.5,1]
xyouts,0.25,0.95,'Pupil shape (pupil plane)',color=255
;;
;; ...On the right: The resulting PSF
;; 
plotimage,alog10(ftabs2[(nx-nwf)/2:(nx+nwf)/2-1,(nx-nwf)/2:(nx+nwf)/2-1]>1d-4),position=[0.5,0,1,1]
plot,[0,1],[0,1],xstyle=7,ystyle=7,/nodata,/noerase,position=[0.5,0,1,1]
xyouts,0.32,0.95,'PSF (image plane)',color=255
end
