@plotimage.pro
;;
fct1=2.    ;; Factor for increasing resolution of map
fct2=1.    ;; Factor for increasing ratio of map size to aperture size
nx=fct1*1024  ;; Total nr of pixels
nwf=0.5*nx*fct2/(2*fct1)   ;; Window in Fourier space to show
nw=2*nx/(4*fct2)    ;; Window in real space to show
xm=10.     ;; Total half-width
r=1./fct2  ;; Radius of the circular aperture
d=3.48*r   ;; Distance between the two circular apertures
xx=rebin(2*xm*dindgen(nx)/(nx-1.d0)-xm,nx,nx)
yy=transpose(xx)
;;
;; Make a circular aperture
;;
mask=dblarr(nx,nx)
rr=sqrt((xx-d/2)^2+yy^2)
ii=where(rr lt r)
mask[ii]=1.d0
rr=sqrt((xx+d/2)^2+yy^2)
ii=where(rr lt r)
mask[ii]=1.d0
;;
;; Make the Fourier transform without support structure
;;
ft=fft(mask)
dum=ft*0
dum[0:nx/2-1,*] = ft[nx/2:nx-1,*]
dum[nx/2:nx-1,*] = ft[0:nx/2-1,*]
ft[*,0:nx/2-1] = dum[*,nx/2:nx-1]
ft[*,nx/2:nx-1] = dum[*,0:nx/2-1]
ftabs2=abs(ft)^2
ftabs2=ftabs2/max(ftabs2)

;;
;; Plot to image
;;
;; In a square
ysize=10
xsize=ysize*2
thick=2.0      ; Postscript line thickness
size=1.0       ; Postscript char size
!p.thick=thick
!x.thick=thick
!y.thick=thick
!z.thick=thick
!p.charthick=thick
!p.charsize=size
set_plot,'ps'
device,file='psf_linc_nirvana.eps',xsize=xsize,ysize=ysize
plotimage,alog10(mask[(nx-nw)/2:(nx+nw)/2-1,(nx-nw)/2:(nx+nw)/2-1]>1d-4),position=[0,0.0,0.5,1]
plot,[0,1],[0,1],xstyle=7,ystyle=7,/nodata,/noerase,position=[0,0.0,0.5,1]
xyouts,0.25,0.95,'Pupil shape (pupil plane)',color=255
plotimage,alog10(ftabs2[(nx-nwf)/2:(nx+nwf)/2-1,(nx-nwf)/2:(nx+nwf)/2-1]>1d-4),position=[0.5,0,1,1]
plot,[0,1],[0,1],xstyle=7,ystyle=7,/nodata,/noerase,position=[0.5,0,1,1]
xyouts,0.32,0.95,'PSF (image plane)',color=255
device,/close
set_plot,'x'
!p.thick=1
!x.thick=1
!y.thick=1
!z.thick=1
!p.charthick=1
!p.charsize=1



end
